package com.nullifier.fileselect;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Base64;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Util {
	/**
	 * 计算一个文件的SHA-1值
	 * 
	 * @param path
	 * @return
	 * @throws OutOfMemoryError
	 * @throws IOException
	 */
	public static String getFileSha1(String path) throws OutOfMemoryError,
			IOException {
		File file = new File(path);
		FileInputStream in = new FileInputStream(file);
		MessageDigest messagedigest;
		try {
			messagedigest = MessageDigest.getInstance("SHA-1");

			byte[] buffer = new byte[1024 * 1024 * 10];
			int len = 0;

			while ((len = in.read(buffer)) > 0) {
				// 该对象通过使用 update（）方法处理数据
				messagedigest.update(buffer, 0, len);
			}

			// 对于给定数量的更新数据，digest 方法只能被调用一次。在调用 digest 之后，MessageDigest
			// 对象被重新设置成其初始状态。
			// return byte2hex(messagedigest.digest());
			// base64编码
			byte[] encode = Base64.getEncoder().encode(messagedigest.digest());
			return new String(encode, "UTF-8");
		} catch (NoSuchAlgorithmException e) {
			e.printStackTrace();
		} catch (OutOfMemoryError e) {

			e.printStackTrace();
			throw e;
		} finally {
			in.close();
		}
		return null;
	}

	/**
	 * 获取目录下所有的文件和SHA-1值，并存储到List中
	 * 
	 * @param path
	 * @throws IOException
	 * @throws OutOfMemoryError
	 */
	public static List<FileInformation> getName(String path)
			throws OutOfMemoryError, IOException {
		List<FileInformation> list = new ArrayList<FileInformation>();

		File file = new File(path);
		if (file.isDirectory()) {
			File[] dirFile = file.listFiles();
			for (File f : dirFile) {
				if (f.isDirectory())
					getName(f.getAbsolutePath());
				else {
					FileInformation fileInformation = new FileInformation();
					fileInformation.setSHA1(getFileSha1(f.getAbsolutePath()));
					fileInformation.setFile(f);
					list.add(fileInformation);
				}
			}
		}
		return list;
	}
}
